@@ -5,7 +5,7 @@ A Python SDK for the TokenRouter API that provides intelligent routing
 to multiple LLM providers with cost optimization.
 """
 
-from .client import Client, AsyncClient
+from .client import TokenRouter, AsyncTokenRouter
 from .models import (
     ChatCompletion,
     ChatCompletionMessage,
@@ -23,10 +23,10 @@ from .exceptions import (
     APIStatusError,
 )
 
-__version__ = "1.0.0"
+__version__ = "1.0.4"
 __all__ = [
-    "Client",
-    "AsyncClient",
+    "TokenRouter",
+    "AsyncTokenRouter",
     "ChatCompletion",
     "ChatCompletionMessage",
     "ChatCompletionChoice",
@@ -39,4 +39,4 @@ __all__ = [
     "InvalidRequestError",
     "APIConnectionError",
     "APIStatusError",
-]
\ No newline at end of file
+]
